@@ -30,14 +30,23 @@ class AIBS(AutoPathMixIn):
         self.AIBS_TENX_SAMPLE_FULL_METADATA_PATH = AIBS_TENX_SAMPLE_FULL_METADATA_PATH
         self.AIBS_TENX_SAMPLE_TOTAL_METADATA_PATH = AIBS_TENX_SAMPLE_TOTAL_METADATA_PATH
         self.AIBS_TENX_SAMPLE_TOTAL_FULL_METADATA_PATH = AIBS_TENX_SAMPLE_TOTAL_FULL_METADATA_PATH
+
         self.AIBS_TENX_ZARR_PATH = AIBS_TENX_ZARR_PATH
+        self.AIBS_TENX_V2_ZARR_PATH = AIBS_TENX_V2_ZARR_PATH
+
         self.AIBS_TENX_OUTLIER_IDS_PATH = AIBS_TENX_OUTLIER_IDS_PATH
-        self.AIBS_TENX_SAMPLE_TYPE_ANNOTATION_PATH = AIBS_TENX_CELL_TYPE_ANNOTATION_PATH
+        self.AIBS_TENX_CELL_TYPE_ANNOTATION_PATH = AIBS_TENX_CELL_TYPE_ANNOTATION_PATH
+        self.AIBS_TENX_CELL_TYPE_ANNOTATION_V2_PATH = AIBS_TENX_CELL_TYPE_ANNOTATION_V2_PATH
         self.AIBS_TENX_GENE_MAP_PATH = AIBS_TENX_GENE_MAP_PATH
 
         self.AIBS_SMART_GENE_CHUNK_ZARR_PATH = AIBS_SMART_GENE_CHUNK_ZARR_PATH
         self.AIBS_TENX_GENE_CHUNK_ZARR_PATH = AIBS_TENX_GENE_CHUNK_ZARR_PATH
 
+        self.AIBS_SMART_CLUSTER_L4_SUM_ZARR_PATH = AIBS_SMART_CLUSTER_L4_SUM_ZARR_PATH
+        self.AIBS_TENX_CLUSTER_L4_SUM_ZARR_PATH = AIBS_TENX_CLUSTER_L4_SUM_ZARR_PATH
+        self.AIBS_SMART_CLUSTER_L4Region_SUM_ZARR_PATH = AIBS_SMART_CLUSTER_L4Region_SUM_ZARR_PATH
+        self.AIBS_TENX_CLUSTER_L4Region_SUM_ZARR_PATH = AIBS_TENX_CLUSTER_L4Region_SUM_ZARR_PATH
+
         # internal variables
         self._smart_gene_zarr = None
         self._smart_cell_million_reads = None
@@ -95,9 +104,19 @@ class AIBS(AutoPathMixIn):
         return AIBSSMARTCellAnnotation(self.AIBS_SMART_CELL_TYPE_ANNOTATION_PATH,
                                        self.get_smart_cell_metadata())
 
-    def get_tenx_annot(self):
-        return AIBSTENXCellAnnotation(self.AIBS_TENX_SAMPLE_TYPE_ANNOTATION_PATH,
-                                      self.get_tenx_sample_metadata())
+    def get_tenx_annot(self, version='v1'):
+        if version == 'v1':
+            path = self.AIBS_TENX_CELL_TYPE_ANNOTATION_PATH
+        elif version == 'v2':
+            path = self.AIBS_TENX_CELL_TYPE_ANNOTATION_V2_PATH
+        else:
+            raise ValueError('Unknown version: {}'.format(version))
+
+        annot = AIBSTENXCellAnnotation(path,
+                                       self.get_tenx_sample_metadata())
+        if version == 'v2':
+            annot.add_palette(palette=PALETTES['AIBS.TENX.Annot.V2'], da_name='L2_annot')
+        return annot
 
     def _open_smart_zarr(self):
         import xarray as xr
